@@ -15,11 +15,13 @@ from .api import (  # noqa: F401
     search_firewall_policy_table_by_addr,
     load_network_graph,
     find_network_nodes_by_ip,
-    find_network_paths
+    find_network_paths,
+    NODE_TYPES,
+    NODE_ANY, NODE_NET, NODE_HOST, NODE_ROUTER, NODE_SWITCH, NODE_FIREWALL
 )
 
 
-__version__ = "0.3.0"
+__version__ = "0.3.2"
 __all__ = """
 parse_and_save_show_configs
 query_json_files
@@ -35,6 +37,13 @@ search_firewall_policy_table_by_addr
 load_network_graph
 find_network_nodes_by_ip
 find_network_paths
+NODE_TYPES
+NODE_ANY
+NODE_NET
+NODE_HOST
+NODE_ROUTER
+NODE_SWITCH
+NODE_FIREWALL
 """.split()
 
 # vim:sw=4:ts=4:et:
